Crate sim_lib_agent_runner_process

Crate sim_lib_agent_runner_process 

Local subprocess-backed model runners for SIM.

Structs

ProcessCommandSpec
Describes a subprocess command invocation and its resource bounds.
ProcessRunner
Local subprocess-backed ModelRunner.

Enums

ProcessProtocol
Wire protocol a ProcessRunner speaks with its subprocess.

Statics

RECIPES
Cookbook recipes for this lib, embedded at build time.

Functions

host_process_capability
Returns the capability gating subprocess execution by a ProcessRunner.
run_process_command
Runs the command in spec, feeding stdin, and returns its captured stdout.
stream_process_command_lines
Runs the command in spec, feeding stdin, invoking on_line for each stdout line as it arrives, and returns the full captured stdout.